@@ -11,15 +11,36 @@ from typing import TypeVar, Final, Type
 from .camel_case_to_underscore import camel_case_to_underscore
 
 
-ENTITY_NAME_FIELD: Final[str] = '__entity_name__'
 Entity = TypeVar('Entity')
+ENTITY_NAME_FIELD: Final[str] = '__entity_name__'
+ENTITY_COLUMNS_FIELD: Final[str] = 'c'
 RELATIONSHIP_COLUMN_SEPARATOR: Final[str] = '.'
 
 
+@dataclass
+class EntityColumn:
+    name: str
+    type: type
+
+
+class ColumnGetter:
+    def __init__(self, entity: Type[Entity]) -> None:
+        self._name_to_column = {
+            name: EntityColumn(name, type_) for name, type_ in entity.__annotations__.items()
+        }
+
+    def __getattr__(self, name: str) -> EntityColumn:
+        column = self._name_to_column.get(name)
+        if column is None:
+            raise AttributeError(f'attribute not found: {name}')
+        return column
+
+
 def entity_dataclass(class_: type = None, *, entity_name: str = None, **kwargs):
     def _entity_dataclass(cls):
         entity = dataclass(cls, **kwargs)
         setattr(entity, ENTITY_NAME_FIELD, entity_name if entity_name else camel_case_to_underscore(cls.__name__))
+        setattr(entity, ENTITY_COLUMNS_FIELD, ColumnGetter(cls))
         return entity
 
     if class_ is None:
@@ -28,9 +49,9 @@ def entity_dataclass(class_: type = None, *, entity_name: str = None, **kwargs):
     return _entity_dataclass(class_)
 
 
-def prepare_entity_column_names(entity: Type[Entity], prefix: str = '') -> list[str]:
+def prepare_entity_column_names(entity_type: Type[Entity], prefix: str = '') -> list[str]:
     result = []
-    for field in fields(entity):
+    for field in fields(entity_type):
         type_origin = getattr(field.type, '__origin__', None)
         type_args = getattr(field.type, '__args__', None)
         if isinstance(type_origin, type):
