@@ -42,7 +42,7 @@ class EntityServerConnector:
                       order_by: EntityOrderProtocol | list[EntityOrderProtocol] | None = None) -> Entity:
         entities = await self.get_list(entity_type, filter_by, search_by, order_by, limit=1)
         if not entities:
-            raise LookupError(f'Undefined {entity_type.__entity_name__}: {filter_by}')
+            raise LookupError(f'Undefined {entity_type.__entity_name__}')
         return first(entities)
 
     async def get_list(self,
